@@ -1,7 +1,7 @@
 /*
  *  be_local.c : backend for the local database
  *
- *  Copyright (c) 2006-2014 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2016 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -63,6 +63,12 @@ static int local_db_read(alpm_pkg_t *info, alpm_dbinfrq_t inforeq);
  * initialized.
  */
 
+static const char *_cache_get_base(alpm_pkg_t *pkg)
+{
+	LAZY_LOAD(INFRQ_DESC, NULL);
+	return pkg->base;
+}
+
 static const char *_cache_get_desc(alpm_pkg_t *pkg)
 {
 	LAZY_LOAD(INFRQ_DESC, NULL);
@@ -297,6 +303,7 @@ static int _cache_force_load(alpm_pkg_t *pkg)
  * logic.
  */
 static struct pkg_operations local_pkg_ops = {
+	.get_base        = _cache_get_base,
 	.get_desc        = _cache_get_desc,
 	.get_url         = _cache_get_url,
 	.get_builddate   = _cache_get_builddate,
@@ -377,6 +384,11 @@ static int local_db_add_version(alpm_db_t UNUSED *db, const char *dbpath)
 	snprintf(dbverpath, PATH_MAX, "%sALPM_DB_VERSION", dbpath);
 
 	dbverfile = fopen(dbverpath, "w");
+
+	if(dbverfile == NULL) {
+		return 1;
+	}
+
 	fprintf(dbverfile, "%zu\n", ALPM_LOCAL_DB_VERSION);
 	fclose(dbverfile);
 
@@ -390,7 +402,10 @@ static int local_db_create(alpm_db_t *db, const char *dbpath)
 				dbpath, strerror(errno));
 		RET_ERR(db->handle, ALPM_ERR_DB_CREATE, -1);
 	}
-	local_db_add_version(db, dbpath);
+	if(local_db_add_version(db, dbpath) != 0) {
+		return 1;
+	}
+
 	return 0;
 }
 
@@ -452,7 +467,9 @@ static int local_db_validate(alpm_db_t *db)
 			}
 		}
 
-		local_db_add_version(db, dbpath);
+		if(local_db_add_version(db, dbpath) != 0) {
+			goto version_error;
+		}
 		goto version_latest;
 	}
 
@@ -701,6 +718,8 @@ static int local_db_read(alpm_pkg_t *info, alpm_dbinfrq_t inforeq)
 					_alpm_log(db->handle, ALPM_LOG_ERROR, _("%s database is inconsistent: version "
 								"mismatch on package %s\n"), db->treename, info->name);
 				}
+			} else if(strcmp(line, "%BASE%") == 0) {
+				READ_AND_STORE(info->base);
 			} else if(strcmp(line, "%DESC%") == 0) {
 				READ_AND_STORE(info->desc);
 			} else if(strcmp(line, "%GROUPS%") == 0) {
@@ -791,9 +810,13 @@ static int local_db_read(alpm_pkg_t *info, alpm_dbinfrq_t inforeq)
 					files_count++;
 				}
 				/* attempt to hand back any memory we don't need */
-				files = realloc(files, sizeof(alpm_file_t) * files_count);
-				/* make sure the list is sorted */
-				qsort(files, files_count, sizeof(alpm_file_t), _alpm_files_cmp);
+				if(files_count > 0) {
+					files = realloc(files, sizeof(alpm_file_t) * files_count);
+					/* make sure the list is sorted */
+					qsort(files, files_count, sizeof(alpm_file_t), _alpm_files_cmp);
+				} else {
+					FREE(files);
+				}
 				info->files.count = files_count;
 				info->files.files = files;
 			} else if(strcmp(line, "%BACKUP%") == 0) {
@@ -801,6 +824,7 @@ static int local_db_read(alpm_pkg_t *info, alpm_dbinfrq_t inforeq)
 					alpm_backup_t *backup;
 					CALLOC(backup, 1, sizeof(alpm_backup_t), goto error);
 					if(_alpm_split_backup(line, &backup)) {
+						FREE(backup);
 						goto error;
 					}
 					info->backup = alpm_list_add(info->backup, backup);
@@ -904,6 +928,10 @@ int _alpm_local_db_write(alpm_db_t *db, alpm_pkg_t *info, alpm_dbinfrq_t inforeq
 		free(path);
 		fprintf(fp, "%%NAME%%\n%s\n\n"
 						"%%VERSION%%\n%s\n\n", info->name, info->version);
+		if(info->base) {
+			fprintf(fp, "%%BASE%%\n"
+							"%s\n\n", info->base);
+		}
 		if(info->desc) {
 			fprintf(fp, "%%DESC%%\n"
 							"%s\n\n", info->desc);
@@ -1022,11 +1050,6 @@ int _alpm_local_db_write(alpm_db_t *db, alpm_pkg_t *info, alpm_dbinfrq_t inforeq
 
 cleanup:
 	umask(oldmask);
-
-	if(fp) {
-		fclose(fp);
-	}
-
 	return retval;
 }
 
