@@ -1,7 +1,7 @@
 /*
  *  deps.c
  *
- *  Copyright (c) 2006-2014 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2016 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *  Copyright (c) 2005 by Aurelien Foret <orelien@chez.com>
  *  Copyright (c) 2005, 2006 by Miklos Vajna <vmiklos@frugalware.org>
@@ -37,6 +37,7 @@
 
 void SYMEXPORT alpm_dep_free(alpm_depend_t *dep)
 {
+	ASSERT(dep != NULL, return);
 	FREE(dep->name);
 	FREE(dep->version);
 	FREE(dep->desc);
@@ -48,17 +49,22 @@ static alpm_depmissing_t *depmiss_new(const char *target, alpm_depend_t *dep,
 {
 	alpm_depmissing_t *miss;
 
-	MALLOC(miss, sizeof(alpm_depmissing_t), return NULL);
+	CALLOC(miss, 1, sizeof(alpm_depmissing_t), return NULL);
 
-	STRDUP(miss->target, target, return NULL);
+	STRDUP(miss->target, target, goto error);
 	miss->depend = _alpm_dep_dup(dep);
-	STRDUP(miss->causingpkg, causingpkg, return NULL);
+	STRDUP(miss->causingpkg, causingpkg, goto error);
 
 	return miss;
+
+error:
+	alpm_depmissing_free(miss);
+	return NULL;
 }
 
 void SYMEXPORT alpm_depmissing_free(alpm_depmissing_t *miss)
 {
+	ASSERT(miss != NULL, return);
 	alpm_dep_free(miss->depend);
 	FREE(miss->target);
 	FREE(miss->causingpkg);
@@ -101,7 +107,13 @@ static alpm_list_t *dep_graph_init(alpm_handle_t *handle,
 	alpm_list_t *i, *j;
 	alpm_list_t *vertices = NULL;
 	alpm_list_t *localpkgs = alpm_list_diff(
-			alpm_db_get_pkgcache(handle->db_local), ignore, _alpm_pkg_cmp);
+			alpm_db_get_pkgcache(handle->db_local), targets, _alpm_pkg_cmp);
+
+	if(ignore) {
+		alpm_list_t *oldlocal = localpkgs;
+		localpkgs = alpm_list_diff(oldlocal, ignore, _alpm_pkg_cmp);
+		alpm_list_free(oldlocal);
+	}
 
 	/* We create the vertices */
 	for(i = targets; i; i = i->next) {
@@ -133,8 +145,7 @@ static alpm_list_t *dep_graph_init(alpm_handle_t *handle,
 				alpm_graph_t *vertex_j = _alpm_graph_new();
 				vertex_j->data = (void *)j->data;
 				vertices = alpm_list_add(vertices, vertex_j);
-				vertex_i->children =
-					alpm_list_add(vertex_i->children, vertex_j);
+				vertex_i->children = alpm_list_add(vertex_i->children, vertex_j);
 				localpkgs = alpm_list_remove_item(localpkgs, j);
 				free(j);
 			}
@@ -465,11 +476,11 @@ alpm_depend_t SYMEXPORT *alpm_dep_from_string(const char *depstring)
 		return NULL;
 	}
 
-	MALLOC(depend, sizeof(alpm_depend_t), return NULL);
+	CALLOC(depend, 1, sizeof(alpm_depend_t), return NULL);
 
 	/* Note the extra space in ": " to avoid matching the epoch */
 	if((desc = strstr(depstring, ": ")) != NULL) {
-		STRDUP(depend->desc, desc + 2, return NULL);
+		STRDUP(depend->desc, desc + 2, goto error);
 		deplen = desc - depstring;
 	} else {
 		/* no description- point desc at NULL at end of string for later use */
@@ -509,13 +520,17 @@ alpm_depend_t SYMEXPORT *alpm_dep_from_string(const char *depstring)
 	}
 
 	/* copy the right parts to the right places */
-	STRNDUP(depend->name, depstring, ptr - depstring, return NULL);
+	STRNDUP(depend->name, depstring, ptr - depstring, goto error);
 	depend->name_hash = _alpm_hash_sdbm(depend->name);
 	if(version) {
-		STRNDUP(depend->version, version, desc - version, return NULL);
+		STRNDUP(depend->version, version, desc - version, goto error);
 	}
 
 	return depend;
+
+error:
+	alpm_dep_free(depend);
+	return NULL;
 }
 
 alpm_depend_t *_alpm_dep_dup(const alpm_depend_t *dep)
@@ -523,13 +538,17 @@ alpm_depend_t *_alpm_dep_dup(const alpm_depend_t *dep)
 	alpm_depend_t *newdep;
 	CALLOC(newdep, 1, sizeof(alpm_depend_t), return NULL);
 
-	STRDUP(newdep->name, dep->name, return NULL);
-	STRDUP(newdep->version, dep->version, return NULL);
-	STRDUP(newdep->desc, dep->desc, return NULL);
+	STRDUP(newdep->name, dep->name, goto error);
+	STRDUP(newdep->version, dep->version, goto error);
+	STRDUP(newdep->desc, dep->desc, goto error);
 	newdep->name_hash = dep->name_hash;
 	newdep->mod = dep->mod;
 
 	return newdep;
+
+error:
+	alpm_dep_free(newdep);
+	return NULL;
 }
 
 /* These parameters are messy. We check if this package, given a list of
@@ -597,11 +616,13 @@ int _alpm_recursedeps(alpm_db_t *db, alpm_list_t **targs, int include_explicit)
 			alpm_pkg_t *deppkg = j->data;
 			if(_alpm_pkg_depends_on(pkg, deppkg)
 					&& can_remove_package(db, deppkg, *targs, include_explicit)) {
-				alpm_pkg_t *copy;
+				alpm_pkg_t *copy = NULL;
 				_alpm_log(db->handle, ALPM_LOG_DEBUG, "adding '%s' to the targets\n",
 						deppkg->name);
 				/* add it to the target list */
 				if(_alpm_pkg_dup(deppkg, &copy)) {
+					/* we return memory on "non-fatal" error in _alpm_pkg_dup */
+					_alpm_pkg_free(copy);
 					return -1;
 				}
 				*targs = alpm_list_add(*targs, copy);
