@@ -1,7 +1,7 @@
 /*
  *  pacman.h
  *
- *  Copyright (c) 2006-2014 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2016 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,8 @@
 int pacman_database(alpm_list_t *targets);
 /* deptest.c */
 int pacman_deptest(alpm_list_t *targets);
+/* files.c */
+int pacman_files(alpm_list_t *files);
 /* query.c */
 int pacman_query(alpm_list_t *targets);
 /* remove.c */
